@@ -3,7 +3,6 @@ import os
 from typing import TypeVar, Type
 
 from ..configuration.models.application import ApplicationConfig
-from ..data import DatabaseSessionManager
 from ..dependency.container import DependencyContainer
 
 T = TypeVar('T')
@@ -22,10 +21,11 @@ class Pdi(object):
         self.excluded_modules = excluded_modules
         self.configurations = configurations
         self.root_directory = root_directory
-        DependencyContainer.initialize_service(root_directory=root_directory,
-                                               configurations=configurations,
-                                               excluded_modules=excluded_modules,
-                                               initialize_flask=initialize_flask)
+        if DependencyContainer.Instance is None:
+            DependencyContainer.initialize_service(root_directory=root_directory,
+                                                   configurations=configurations,
+                                                   excluded_modules=excluded_modules,
+                                                   initialize_flask=initialize_flask)
 
     def cleanup(self):
         DependencyContainer.cleanup()
@@ -39,5 +39,6 @@ class Pdi(object):
     def get(self, instance_type: Type[T]) -> T:
         return DependencyContainer.Instance.get(instance_type)
 
-    def set_secret_key(self,key):
-        DependencyContainer.Instance.config_manager.set(ApplicationConfig, 'secret_key', key)
\ No newline at end of file
+    def set_secret_key(self, key):
+        DependencyContainer.Instance.config_manager.set(
+            ApplicationConfig, 'secret_key', key)
